==> slack_logging-1.1.1.tar.gz: slack_logging-1.1.1/slack_logging/handlers.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import logging
import ujson

import requests

from slack_logging.integrations import WebHooks


class SlackLoggerHandler(logging.Handler):
    """
    Handler for the slack logger.
    Creates a Thread to send the slack message.
    Should be used with the formatter: SlackLoggerFormatter
    """

    @property
    def valid_webhooks(self):
        """
        Fetch the webhooks that should receive the log message
        :rtype: list[tuple[str,str]]
        """
        webhooks = [(c.webhook, c.name) for l, c in WebHooks.items() if not l or l == logging._checkLevel(self.level)]
        if not webhooks:
            raise RuntimeError('No Slack webhooks are configured!')
        return webhooks

    def emit(self, record):
        """
        If inheriting from logging.Handler you must overwrite the emit function.
        :param record: The logger record to be sent
        """
        try:
            formatted_record = self.format(record)

            for webhook, channel in self.valid_webhooks:

                payload = ujson.dumps({'text': formatted_record, 'username': record.name, 'channel': channel})

                requests.post(url=webhook, headers={'Content-Type': 'application/json'}, data=payload, timeout=5)

        except (KeyboardInterrupt, SystemExit, RuntimeError):
            raise
        except (Exception, ):
            self.handleError(record)

    def __eq__(self, other):
        """Compare objects except the lock state (set to None for no comparison)"""
        return dict(self.__dict__, lock=None) == dict(other.__dict__, lock=None)

==> slack_logging-1.1.2.tar.gz: slack_logging-1.1.2/slack_logging/handlers.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import logging
import ujson

import requests

from slack_logging.integrations import WebHooks


class SlackLoggerHandler(logging.Handler):
    """
    Handler for the slack logger.
    Creates a Thread to send the slack message.
    Should be used with the formatter: SlackLoggerFormatter
    """

    @property
    def valid_webhooks(self):
        """
        Fetch the webhooks that should receive the log message
        :rtype: list[tuple[str,str]]
        """
        webhooks = [(c.webhook, c.name) for l, c in WebHooks.items() if not l or not self.level or l == self.level]
        if not webhooks:
            raise RuntimeError('No Slack webhooks are configured!')
        return webhooks

    def emit(self, record):
        """
        If inheriting from logging.Handler you must overwrite the emit function.
        :param record: The logger record to be sent
        """
        try:
            formatted_record = self.format(record)

            for webhook, channel in self.valid_webhooks:

                payload = ujson.dumps({'text': formatted_record, 'username': record.name, 'channel': channel})

                requests.post(url=webhook, headers={'Content-Type': 'application/json'}, data=payload, timeout=5)

        except (KeyboardInterrupt, SystemExit, RuntimeError):
            raise
        except (Exception, ):
            self.handleError(record)

    def __eq__(self, other):
        """Compare objects except the lock state (set to None for no comparison)"""
        return dict(self.__dict__, lock=None) == dict(other.__dict__, lock=None)
